@@ -571,7 +571,7 @@ syn.ctree <- function(y, x, xp, smoothing, proper = FALSE, minbucket = 5, ... )
 }
 
 
-###-----survctree---------------------------------------------------------
+###-----syn.survctree------------------------------------------------------
 
 syn.survctree <- function(y, yevent, x, xp, proper = FALSE, minbucket = 5, ...)
 # time, event - data column numbers
@@ -605,6 +605,91 @@ syn.survctree <- function(y, yevent, x, xp, proper = FALSE, minbucket = 5, ...)
 }
 
 
+###-----syn.rf-------------------------------------------------------------
+# bagging when mtry = ncol(x) - using all predictors
+syn.rf <- function(y, x, xp, smoothing, proper = FALSE, ntree = 10, ...) 
+{ 
+  #nodesize <- max(1, nodesize)  # safety
+  #if (proper == TRUE) {
+  #  s <- sample(length(y), replace = T); y <- y[s]
+  #  x <- x[s, , drop = FALSE]
+  #}  
+
+  for (i in which(sapply(x,class)!=sapply(xp,class))) xp[,i] <-
+  eval(parse(text=paste0("as.",class(x[,i]),"(xp[,i])",sep="")))
+  
+  if (is.factor(y)){
+    obslevels <- levels(y)
+    y <- droplevels(y)
+  }
+
+  # fit a random forest
+  # regression (mtry=p/3), classification (mtry=sqrt(p))
+  rf.fit <- randomForest(y ~ ., data = cbind.data.frame(y,x), ntree = ntree, ...)
+  nodessyn <- attr(predict(rf.fit, newdata = xp, nodes = T), "nodes")
+  nodesobs <- attr(predict(rf.fit, newdata = x, nodes = T), "nodes")
+
+  ndonors <- vector("list", nrow(xp))
+  n0      <- vector("list", ntree)
+  for (j in 1:nrow(xp)){
+    for (i in 1:ntree) {
+      n0[[i]] <- y[nodesobs[,i]==nodessyn[j,i]]
+    }
+    empty <- sapply(n0, length)
+    ndonors[[j]] <- unlist(n0[empty!=0])
+  }
+  
+  yhat <- sapply(ndonors, sample, size=1)          
+  
+  if (is.factor(y)) yhat <- factor(yhat, levels = obslevels) 
+  if (!is.factor(y) & smoothing=="density") yhat <- syn.smooth(yhat,y)
+    
+  return(yhat)
+}
+
+###-----syn.bag-------------------------------------------------------------
+# bagging when mtry = ncol(x) - using all predictors
+syn.bag <- function(y, x, xp, smoothing, proper = FALSE, ntree = 10, ...) 
+{ 
+  #nodesize <- max(1, nodesize)  # safety
+  #if (proper == TRUE) {
+  #  s <- sample(length(y), replace = T); y <- y[s]
+  #  x <- x[s, , drop = FALSE]
+  #}  
+
+  for (i in which(sapply(x,class)!=sapply(xp,class))) xp[,i] <-
+  eval(parse(text=paste0("as.",class(x[,i]),"(xp[,i])",sep="")))
+  
+  if (is.factor(y)){
+    obslevels <- levels(y)
+    y <- droplevels(y)
+  }
+
+  # fit a random forest
+  # regression (mtry=p/3), classification (mtry=sqrt(p))
+  rf.fit <- randomForest(y ~ ., data = cbind.data.frame(y,x), ntree = ntree, mtry = ncol(x), ...)
+  nodessyn <- attr(predict(rf.fit, newdata = xp, nodes = T), "nodes")
+  nodesobs <- attr(predict(rf.fit, newdata = x, nodes = T), "nodes")
+
+  ndonors <- vector("list", nrow(xp))
+  n0      <- vector("list", ntree)
+  for (j in 1:nrow(xp)){
+    for (i in 1:ntree) {
+      n0[[i]] <- y[nodesobs[,i]==nodessyn[j,i]]
+    }
+    empty <- sapply(n0, length)
+    ndonors[[j]] <- unlist(n0[empty!=0])
+  }
+  
+  yhat <- sapply(ndonors, sample, size=1)
+  
+  if (is.factor(y)) yhat <- factor(yhat, levels = obslevels) 
+  if (!is.factor(y) & smoothing=="density") yhat <- syn.smooth(yhat,y)
+    
+  return(yhat)
+}
+
+
 ###-----syn.cartbboot-----------------------------------------------------
 
 syn.cartbboot <- function(y, x, xp, proper = FALSE, 
